@@ -9,7 +9,13 @@ pub struct EnvKeys {
 impl EnvKeys {
     pub async fn run(&self) -> VfoxResult<()> {
         let vfox = Vfox::new();
-        let env_keys = vfox.env_keys(&self.sdk, &self.version).await?;
+        let env_keys = vfox
+            .env_keys(
+                &self.sdk,
+                &self.version,
+                serde_json::Value::Object(Default::default()),
+            )
+            .await?;
         for env_key in env_keys {
             println!("{}={}", env_key.key, env_key.value);
         }
