@@ -93,7 +93,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_path_env() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         let mut path_env = PathEnv::from_iter(
             [
                 "/before-1",
@@ -117,7 +117,7 @@ mod tests {
 
     #[tokio::test]
     async fn test_path_env_no_mise() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         let mut path_env = PathEnv::from_iter(
             [
                 "/before-1",
@@ -139,7 +139,7 @@ mod tests {
     }
     #[tokio::test]
     async fn test_path_env_with_colon() {
-        let _config = Config::get().await;
+        let _config = Config::get().await.unwrap();
         let mut path_env = PathEnv::from_iter(["/item1", "/item2"].map(PathBuf::from));
         path_env.add("/1:/2".into());
         assert_eq!(path_env.to_string(), format!("/1:/2:/item1:/item2"));
